var _a, _b;
import _ from "lodash";
import { ChainId, supportedChainIds } from "../common/chainid.js";
import { RpcConnector } from "./rpcconnector.js";
var RPC_URI_SUFFIX = "RPC_URI";
var makeRpcUriEnvKey = function (chainId) {
    var key = _.findKey(ChainId, function (o) { return o === chainId; });
    return "".concat(key, "_").concat(RPC_URI_SUFFIX);
};
var ENV_KEY_MAP = (_a = {},
    _a[ChainId.ETH] = makeRpcUriEnvKey(ChainId.ETH),
    _a[ChainId.OPTIMISM] = makeRpcUriEnvKey(ChainId.OPTIMISM),
    _a[ChainId.CRONOS] = makeRpcUriEnvKey(ChainId.CRONOS),
    _a[ChainId.BSC] = makeRpcUriEnvKey(ChainId.BSC),
    _a[ChainId.POLYGON] = makeRpcUriEnvKey(ChainId.POLYGON),
    _a[ChainId.FANTOM] = makeRpcUriEnvKey(ChainId.FANTOM),
    _a[ChainId.BOBA] = makeRpcUriEnvKey(ChainId.BOBA),
    _a[ChainId.METIS] = makeRpcUriEnvKey(ChainId.METIS),
    _a[ChainId.MOONBEAM] = makeRpcUriEnvKey(ChainId.MOONBEAM),
    _a[ChainId.MOONRIVER] = makeRpcUriEnvKey(ChainId.MOONRIVER),
    _a[ChainId.ARBITRUM] = makeRpcUriEnvKey(ChainId.ARBITRUM),
    _a[ChainId.AVALANCHE] = makeRpcUriEnvKey(ChainId.AVALANCHE),
    _a[ChainId.DFK] = makeRpcUriEnvKey(ChainId.DFK),
    _a[ChainId.AURORA] = makeRpcUriEnvKey(ChainId.AURORA),
    _a[ChainId.HARMONY] = makeRpcUriEnvKey(ChainId.HARMONY),
    _a);
var CHAIN_RPC_URIS = (_b = {},
    _b[ChainId.ETH] = "https://mainnet.infura.io/v3/9aa3d95b3bc440fa88ea12eaa4456161",
    _b[ChainId.OPTIMISM] = "https://mainnet.optimism.io",
    _b[ChainId.CRONOS] = "https://evm-cronos.crypto.org",
    _b[ChainId.BSC] = "https://bsc-dataseed.binance.org/",
    _b[ChainId.POLYGON] = "https://polygon-rpc.com/",
    _b[ChainId.FANTOM] = "https://rpc.ftm.tools/",
    _b[ChainId.BOBA] = "https://replica-oolong.boba.network/",
    _b[ChainId.METIS] = "https://andromeda.metis.io/?owner=1088",
    _b[ChainId.MOONBEAM] = "https://rpc.api.moonbeam.network",
    _b[ChainId.MOONRIVER] = "https://rpc.api.moonriver.moonbeam.network",
    _b[ChainId.ARBITRUM] = "https://arb1.arbitrum.io/rpc",
    _b[ChainId.AVALANCHE] = "https://api.avax.network/ext/bc/C/rpc",
    _b[ChainId.DFK] = "https://subnets.avax.network/defi-kingdoms/dfk-chain/rpc",
    _b[ChainId.AURORA] = "https://mainnet.aurora.dev",
    _b[ChainId.HARMONY] = "https://api.harmony.one/",
    _b);
var CHAINID_URI_MAP = _.fromPairs(supportedChainIds().map(function (cid) { return [cid, getChainRpcUri(cid)]; }));
var RPC_BATCH_INTERVAL = Number(process.env["RPC_BATCH_INTERVAL"]) || 60;
var RPC_CONNECTOR = new RpcConnector({
    urls: CHAINID_URI_MAP,
    batchInterval: RPC_BATCH_INTERVAL
});
export function getChainRpcUri(chainId) {
    var rpcEnvKey = ENV_KEY_MAP[chainId], rpcEnvVal = rpcEnvKey in process.env ? process.env[rpcEnvKey] : undefined;
    return rpcEnvVal !== null && rpcEnvVal !== void 0 ? rpcEnvVal : CHAIN_RPC_URIS[chainId];
}
/**
 * @param chainId chain id of the network for which to return a provider
 */
export function rpcProviderForChain(chainId) {
    return RPC_CONNECTOR.provider(chainId);
}
export function configureRPCEndpoints(config) {
    for (var _i = 0, _a = supportedChainIds(); _i < _a.length; _i++) {
        var chainId = _a[_i];
        if (config[chainId]) {
            var _b = config[chainId], endpoint = _b.endpoint, batchInterval = _b.batchInterval;
            RPC_CONNECTOR.setProviderConfig(chainId, endpoint, batchInterval);
        }
    }
}
